@@ -3,16 +3,24 @@ use warnings;
 use strict;
 use lib '/home/ben/projects/C-Tokenize/lib';
 use C::Tokenize qw/tokenize @fields/;
-use Deploy 'file_slurp';
+use File::Slurp;
 
 =head1 NAME
 
 c2html - convert C program text into HTML
 
+=head1 SYNOPSIS
+
+    c2html bug.c > bug.c.html
+
+The output HTML probably requires editing to be useful.
+
+Requires L<File::Slurp> (not a distribution dependency).
+
 =cut
 
 for my $file (@ARGV) {
-    my $text = file_slurp ($file);
+    my $text = read_file ($file);
     my $tokens = tokenize ($text);
     my $html = make_html ($tokens);
     $html = boilerplate ($html, $file);
